NetworkKey

Struct NetworkKey 

#[repr(C)]
pub struct NetworkKey(pub [u8; 32]);
The network key, or network identifier, used during the secret handshake to prove that both parties are participating in the same ssb network.

The main ssb network uses a publicly-known key, which is available as NetworkKey::SSB_MAIN_NET.

This is an HMAC key; specifically HMAC-SHA-512-256.

Tuple Fields

0: [u8; 32]

Implementations

Source

impl NetworkKey

pub const SIZE: usize

The size of a NetworkKey, in bytes (32).

pub const SSB_MAIN_NET: NetworkKey

The NetworkKey for the primary ssb network.

pub fn from_slice(s: &[u8]) -> Option<Self>

Deserialize from a slice of bytes. Returns None if the slice length isn’t 32.

pub fn generate_with_rng<R>(r: &mut R) -> NetworkKey
where R: CryptoRng + RngCore,

Generate a random network key using the given cryptographically-secure random number generator.

pub fn from_base64(s: &str) -> Option<Self>

Deserialize from the base-64 representation.

Source

impl NetworkKey

pub fn authenticate(&self, b: &[u8]) -> NetworkAuth

Generate an authentication code for the given byte slice.

Examples
use ssb_crypto::NetworkKey;
let netkey = NetworkKey::SSB_MAIN_NET;
let bytes = [1, 2, 3, 4];
let auth = netkey.authenticate(&bytes);
assert!(netkey.verify(&auth, &bytes));
pub fn verify(&self, auth: &NetworkAuth, b: &[u8]) -> bool

Verify that an authentication code was generated by this key, given the same byte slice.

pub fn generate() -> NetworkKey

Generate a random network key.

Examples
use ssb_crypto::NetworkKey;
let key = NetworkKey::generate();
assert_ne!(key, NetworkKey::SSB_MAIN_NET);